@@ -168,7 +168,7 @@ class Bigoyster:
 
     def get_consumer_coupons(
         self, device_id, consumer_id, upcs='', qtys='', prices='', txn_line_refs='', txn_ref='',
-        txn_type='sale', sale_auth='', sale_txn_ref='', sale_txn_ref_lines=''
+        txn_type='sale', sale_auth='', sale_txn_ref='', sale_txn_ref_lines='', taxes=[]
     ):
         if txn_type == 'return' and not sale_auth:
             raise Exception('No auth code on refund')
@@ -184,6 +184,7 @@ class Bigoyster:
         :param txn_ref: string
         :param txn_type: string options: sale, return
         :param sale_auth: string only for returns, original sale auth_code
+        :param taxes: list of json of taxes summed for order total
         :return:
         """
         # authorization code
@@ -202,7 +203,8 @@ class Bigoyster:
             'txn_type': txn_type,
             'sale_auth': sale_auth,
             'sale_txn_ref': sale_txn_ref,
-            'sale_txn_ref_lines': sale_txn_ref_lines
+            'sale_txn_ref_lines': sale_txn_ref_lines,
+            'taxes': taxes
         }
         # check if preprocessing required
         x = upcs.split(',')
@@ -284,6 +286,12 @@ class Bigoyster:
         result = self.call_list_api('tag', params=params).get('results')
         return result
 
+    def get_periods(self):
+        params = {
+            "available_retail": True
+        }
+        return self.call_list_api('period', params=params).get('results')
+
     def create_store_coupon(self, device_id, headline, description, image_b64, customer_ref, categories, callback='', selected_periods=[]):
         if not device_id:
             raise Exception('NO DEVICE')
